@@ -162,22 +162,15 @@ comments_get_comment_filename (const char *source,
 	source_real = g_strdup (source);
 
 	if (resolve_symlinks) {
-		char           *parent;
-		char           *parent_resolved;
+		char           *source_resolved;
 		GnomeVFSResult  result;
 
-		parent = remove_level_from_path (source);
-		result = resolve_all_symlinks (parent, &parent_resolved);
-		g_free (parent);
+		result = resolve_all_symlinks (source, &source_resolved);
 
 		if (result == GNOME_VFS_OK) { 
 			g_free (source_real);
-			source_real = g_strconcat (parent_resolved, 
-						   "/",
-						   file_name_from_path (source),
-						   NULL);
-			g_free (parent_resolved);
-		} 
+			source_real = source_resolved;
+		}
 	}
 
 	directory = remove_level_from_path (source_real);
@@ -220,9 +213,6 @@ comments_get_comment_dir (const char *directory,
 		result = resolve_all_symlinks (directory, &directory_resolved);
 		if (result == GNOME_VFS_OK) 
 			directory_real = directory_resolved;
-		else
-			g_print ("ERROR: %s\n", gnome_vfs_result_to_string (result));
-		g_print ("RESOLVED: %s\n", directory_resolved);
 	}
 
 	if (directory_real == NULL)
@@ -630,6 +620,7 @@ save_comment (const char  *filename,
 	/* Write to disk. */
 
 	comment_file = comments_get_comment_filename (filename, TRUE, TRUE);
+
 	dest_dir = remove_level_from_path (comment_file);
 	if (ensure_dir_exists (dest_dir, 0700)) {
 		xmlSetDocCompressMode (doc, 3);
@@ -753,9 +744,11 @@ comments_get_comment_as_string (CommentData *data,
 {
 	char      *as_string = NULL;
 	char       time_txt[50];
+	char      *utf8_time_txt = NULL;
 	struct tm *tm;
 
-	if (data == NULL) return NULL;
+	if (data == NULL)
+		return NULL;
  
 	if (data->time != 0) {
 		tm = localtime (& data->time);
@@ -763,8 +756,8 @@ comments_get_comment_as_string (CommentData *data,
 			strftime (time_txt, 50, _("%d %B %Y"), tm);
 		else
 			strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
-	} else
-		time_txt[0] = 0;
+		utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
+	} 
 
 	if ((data->comment == NULL) 
 	    && (data->place == NULL) 
@@ -791,13 +784,15 @@ comments_get_comment_as_string (CommentData *data,
 		if ((data->place != NULL) && (*time_txt != 0))
 			g_string_append (comment, sep2);
 
-		if (*time_txt != 0) 
-			g_string_append (comment, time_txt);
+		if (utf8_time_txt != NULL) 
+			g_string_append (comment, utf8_time_txt);
 
 		as_string = comment->str;
 		g_string_free (comment, FALSE);
 	}
 
+	g_free (utf8_time_txt);
+
 	return as_string;
 }
 
