@@ -38,15 +38,17 @@
 #include "gtk-utils.h"
 #include "gth-file-view.h"
 #include "comments.h"
-#include "exif-utils.h"
+#include "gth-exif-utils.h"
 
 
 enum {
 	NO_DATE = 0,
 	FOLLOWING_DATE,
 	CURRENT_DATE,
+	EXIF_DATE,
+	LAST_MODIFIED_DATE,
 	IMAGE_CREATION_DATE,
-	EXIF_DATE
+	N_DATE_OPTIONS
 };
 
 
@@ -133,14 +135,17 @@ get_requested_time (DialogData *data,
 	case CURRENT_DATE:
 		t = time (NULL);
 		break;
-	case IMAGE_CREATION_DATE:
-		t = get_file_ctime (filename);
-		break;
 	case EXIF_DATE:
 #ifdef HAVE_LIBEXIF
 		t = get_exif_time (filename);
 #endif
 		break;
+	case LAST_MODIFIED_DATE:
+		t = get_file_mtime (filename);
+		break;
+	case IMAGE_CREATION_DATE:
+		t = get_file_ctime (filename);
+		break;
 	}
 
 	return t;
@@ -289,7 +294,6 @@ date_optionmenu_changed_cb (GtkOptionMenu *option_menu,
 
 	switch (idx) {
 	case NO_DATE:
-		break;
 	case FOLLOWING_DATE:
 		break;
 	case CURRENT_DATE:
@@ -301,6 +305,10 @@ date_optionmenu_changed_cb (GtkOptionMenu *option_menu,
 		gnome_date_edit_set_time (GNOME_DATE_EDIT (data->date_dateedit), 
 					  get_file_ctime (first_image));
 		break;
+	case LAST_MODIFIED_DATE:
+		gnome_date_edit_set_time (GNOME_DATE_EDIT (data->date_dateedit), 
+					  get_file_mtime (first_image));
+		break;
 	case EXIF_DATE:
 #ifdef HAVE_LIBEXIF
 		gnome_date_edit_set_time (GNOME_DATE_EDIT (data->date_dateedit),
@@ -507,6 +515,6 @@ dlg_edit_comment (GtkWidget *widget, gpointer wdata)
 			gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (parent_win));
 	}
 
-	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 	gtk_widget_show (data->dialog);
 }
